@@ -7,7 +7,7 @@ use warnings;
 
 # VERSION
 
-our $VERSION = '1.00';
+our $VERSION = '1.01';
 
 # AUTHORITY
 
@@ -99,7 +99,7 @@ OO Standard Library for Perl 5
 
 =head1 VERSION
 
-1.00
+1.01
 
 =cut
 
@@ -176,7 +176,7 @@ I<Since C<0.01>>
 
   $error;
 
-  # 'Died at ...'
+  # "Died at ..."
 
 =back
 
@@ -192,7 +192,7 @@ I<Since C<0.01>>
 
   $error;
 
-  # Venus::Error
+  # bless({...}, 'Venus::Error')
 
 =back
 
@@ -801,6 +801,7 @@ B<example 1>
 
   use Venus::Class;
 
+  with 'Venus::Role::Tryable';
   with 'Venus::Role::Throwable';
   with 'Venus::Role::Catchable';
 
