@@ -5,9 +5,9 @@ use 5.018;
 use strict;
 use warnings;
 
-use Moo;
+use Venus::Class;
 
-extends 'Venus::Kind::Value';
+base 'Venus::Kind::Value';
 
 with 'Venus::Role::Mappable';
 
@@ -24,28 +24,6 @@ sub build_args {
   };
 }
 
-# MODIFIERS
-
-around get => sub {
-  my ($orig, $self, @args) = @_;
-
-  return $self->$orig if $#_ < 2;
-
-  my ($index) = @args;
-
-  return $self->value->{$index};
-};
-
-around set => sub {
-  my ($orig, $self, @args) = @_;
-
-  return $self->$orig(@args) if $#_ < 3;
-
-  my ($index, $value) = @args;
-
-  return $self->value->{$index} = $value;
-};
-
 # METHODS
 
 sub all {
@@ -176,6 +154,16 @@ sub find {
   return wantarray ? ($item, int(!!$seen)) : $item;
 }
 
+sub get {
+  my ($self, @args) = @_;
+
+  return $self->value if !int@args;
+
+  my ($index) = @args;
+
+  return $self->value->{$index};
+}
+
 sub grep {
   my ($self, $code) = @_;
 
@@ -381,6 +369,16 @@ sub reverse {
   return {CORE::reverse(%$result)};
 }
 
+sub set {
+  my ($self, @args) = @_;
+
+  return $self->value if !int@args;
+
+  my ($index, $value) = @args;
+
+  return $self->value->{$index} = $value;
+}
+
 sub slice {
   my ($self, @args) = @_;
 
