@@ -15,11 +15,22 @@ use Venus::Class;
 
 base 'Venus::Kind';
 
+with 'Venus::Role::Valuable';
 with 'Venus::Role::Buildable';
 with 'Venus::Role::Accessible';
 with 'Venus::Role::Explainable';
+with 'Venus::Role::Proxyable';
 with 'Venus::Role::Pluggable';
-with 'Venus::Role::Valuable';
+
+# BUILDERS
+
+sub build_arg {
+  my ($self, $data) = @_;
+
+  return {
+    value => $data,
+  };
+}
 
 # METHODS
 
