@@ -9,6 +9,8 @@ use Venus::Class;
 
 base 'Venus::Kind::Utility';
 
+with 'Venus::Role::Valuable';
+with 'Venus::Role::Buildable';
 with 'Venus::Role::Accessible';
 
 use Scalar::Util ();
@@ -261,6 +263,10 @@ This package integrates behaviors from:
 
 L<Venus::Role::Accessible>
 
+L<Venus::Role::Buildable>
+
+L<Venus::Role::Valuable>
+
 =cut
 
 =head1 METHODS
