@@ -9,6 +9,8 @@ use Venus::Class 'base', 'with';
 
 base 'Venus::Kind::Utility';
 
+with 'Venus::Role::Valuable';
+with 'Venus::Role::Buildable';
 with 'Venus::Role::Accessible';
 with 'Venus::Role::Explainable';
 
@@ -570,8 +572,12 @@ This package integrates behaviors from:
 
 L<Venus::Role::Accessible>
 
+L<Venus::Role::Buildable>
+
 L<Venus::Role::Explainable>
 
+L<Venus::Role::Valuable>
+
 =cut
 
 =head1 METHODS
