@@ -37,12 +37,21 @@ sub import {
   if ($exports{"base"} && !*{"${from}::base"}{"CODE"}) {
     *{"${from}::base"} = sub {@_ = ($from, @_); goto \&base};
   }
+  if ($exports{"catch"} && !*{"${from}::catch"}{"CODE"}) {
+    *{"${from}::catch"} = sub (&) {require Venus; goto \&Venus::catch};
+  }
+  if ($exports{"error"} && !*{"${from}::error"}{"CODE"}) {
+    *{"${from}::error"} = sub (;$) {require Venus; goto \&Venus::error};
+  }
   if (!*{"${from}::false"}{"CODE"}) {
     *{"${from}::false"} = sub {require Venus; Venus::false()};
   }
   if ($exports{"from"} && !*{"${from}::from"}{"CODE"}) {
     *{"${from}::from"} = sub {@_ = ($from, @_); goto \&from};
   }
+  if ($exports{"raise"} && !*{"${from}::raise"}{"CODE"}) {
+    *{"${from}::raise"} = sub ($;$) {require Venus; goto \&Venus::raise};
+  }
   if ($exports{"role"} && !*{"${from}::role"}{"CODE"}) {
     *{"${from}::role"} = sub {@_ = ($from, @_); goto \&role};
   }
@@ -204,9 +213,9 @@ automatically by the L<"test"|Venus::Class/test> function.
 
 =cut
 
-=head1 METHODS
+=head1 FUNCTIONS
 
-This package provides the following methods:
+This package provides the following functions:
 
 =cut
 
@@ -217,7 +226,7 @@ This package provides the following methods:
 The attr function creates attribute accessors for the calling package. This
 function is always exported unless a routine of the same name already exists.
 
-I<Since C<0.10>>
+I<Since C<1.00>>
 
 =over 4
 
@@ -243,7 +252,7 @@ The base function registers one or more base classes for the calling package.
 This function is always exported unless a routine of the same name already
 exists.
 
-I<Since C<0.10>>
+I<Since C<1.00>>
 
 =over 4
 
@@ -269,6 +278,95 @@ I<Since C<0.10>>
 
 =cut
 
+=head2 catch
+
+  catch(CodeRef $block) (Error, Any)
+
+The catch function executes the code block trapping errors and returning the
+caught exception in scalar context, and also returning the result as a second
+argument in list context. This function isn't export unless requested.
+
+I<Since C<1.01>>
+
+=over 4
+
+=item catch example 1
+
+  package Ability;
+
+  use Venus::Role 'catch';
+
+  sub attempt_catch {
+    catch {die};
+  }
+
+  sub EXPORT {
+    ['attempt_catch']
+  }
+
+  package Example;
+
+  use Venus::Class 'with';
+
+  with 'Ability';
+
+  package main;
+
+  my $example = Example->new;
+
+  my $error = $example->attempt_catch;
+
+  $error;
+
+  # "Died at ..."
+
+=back
+
+=cut
+
+=head2 error
+
+  error(Maybe[HashRef] $args) (Error)
+
+The error function throws a L<Venus::Error> exception object using the
+exception object arguments provided. This function isn't export unless requested.
+
+I<Since C<1.01>>
+
+=over 4
+
+=item error example 1
+
+  package Ability;
+
+  use Venus::Role 'error';
+
+  sub attempt_error {
+    error;
+  }
+
+  sub EXPORT {
+    ['attempt_error']
+  }
+
+  package Example;
+
+  use Venus::Class 'with';
+
+  with 'Ability';
+
+  package main;
+
+  my $example = Example->new;
+
+  my $error = $example->attempt_error;
+
+  # bless({...}, 'Venus::Error')
+
+=back
+
+=cut
+
 =head2 false
 
   false() (Bool)
@@ -277,7 +375,7 @@ The false function returns a falsy boolean value which is designed to be
 practically indistinguishable from the conventional numerical C<0> value. This
 function is always exported unless a routine of the same name already exists.
 
-I<Since C<0.10>>
+I<Since C<1.00>>
 
 =over 4
 
@@ -317,7 +415,7 @@ The from function registers one or more base classes for the calling package
 and performs an L<"audit"|Venus::Core/AUDIT>. This function is always exported
 unless a routine of the same name already exists.
 
-I<Since C<0.10>>
+I<Since C<1.00>>
 
 =over 4
 
@@ -358,6 +456,50 @@ I<Since C<0.10>>
 
 =cut
 
+=head2 raise
+
+  raise(Str $class | Tuple[Str, Str] $class, Maybe[HashRef] $args) (Error)
+
+The raise function generates and throws a named exception object derived from
+L<Venus::Error>, or provided base class, using the exception object arguments
+provided. This function isn't export unless requested.
+
+I<Since C<1.01>>
+
+=over 4
+
+=item raise example 1
+
+  package Ability;
+
+  use Venus::Role 'raise';
+
+  sub attempt_raise {
+    raise 'Example::Error';
+  }
+
+  sub EXPORT {
+    ['attempt_raise']
+  }
+
+  package Example;
+
+  use Venus::Class 'with';
+
+  with 'Ability';
+
+  package main;
+
+  my $example = Example->new;
+
+  my $error = $example->attempt_raise;
+
+  # bless({...}, 'Example::Error')
+
+=back
+
+=cut
+
 =head2 role
 
   role(Str $name) (Str)
@@ -365,7 +507,7 @@ I<Since C<0.10>>
 The role function registers and consumes roles for the calling package. This
 function is always exported unless a routine of the same name already exists.
 
-I<Since C<0.10>>
+I<Since C<1.00>>
 
 =over 4
 
@@ -426,7 +568,7 @@ performs an L<"audit"|Venus::Core/AUDIT>, effectively allowing a role to act as
 an interface. This function is always exported unless a routine of the same
 name already exists.
 
-I<Since C<0.10>>
+I<Since C<1.00>>
 
 =over 4
 
@@ -478,7 +620,7 @@ The true function returns a truthy boolean value which is designed to be
 practically indistinguishable from the conventional numerical C<1> value. This
 function is always exported unless a routine of the same name already exists.
 
-I<Since C<0.10>>
+I<Since C<1.00>>
 
 =over 4
 
@@ -519,7 +661,7 @@ function is an alias of the L</test> function and will perform an
 L<"audit"|Venus::Core/AUDIT> if present. This function is always exported
 unless a routine of the same name already exists.
 
-I<Since C<0.10>>
+I<Since C<1.00>>
 
 =over 4
 
