@@ -7,7 +7,17 @@ use warnings;
 
 use Venus::Role 'with';
 
-with 'Venus::Role::Dumpable';
+# AUDITS
+
+sub AUDIT {
+  my ($self, $from) = @_;
+
+  if (!$from->does('Venus::Role::Dumpable')) {
+    die "${self} requires ${from} to consume Venus::Role::Dumpable";
+  }
+
+  return $self;
+}
 
 # METHODS
 
@@ -57,8 +67,6 @@ sub say_string {
 
 sub EXPORT {
   [
-    'dump',
-    'dump_pretty',
     'print',
     'print_pretty',
     'print_string',
@@ -91,6 +99,7 @@ Printable Role for Perl 5
 
   use Venus::Class;
 
+  with 'Venus::Role::Dumpable';
   with 'Venus::Role::Printable';
 
   attr 'test';
@@ -118,14 +127,6 @@ return value of a dispatched method call to STDOUT.
 
 =cut
 
-=head1 INTEGRATES
-
-This package integrates behaviors from:
-
-L<Venus::Role::Dumpable>
-
-=cut
-
 =head1 METHODS
 
 This package provides the following methods:
