@@ -5,15 +5,16 @@ use 5.018;
 use strict;
 use warnings;
 
-use Moo;
+use Venus::Class;
 
-extends 'Venus::Kind::Value';
+base 'Venus::Kind::Value';
 
 use overload (
   '.' => sub{$_[0]->value . "$_[1]"},
   'eq' => sub{$_[0]->value eq "$_[1]"},
   'ne' => sub{$_[0]->value ne "$_[1]"},
   'qr' => sub{qr/@{[quotemeta($_[0]->value)]}/},
+  fallback => 1,
 );
 
 # METHODS
@@ -42,7 +43,7 @@ sub camelcase {
   $result =~ s/[^a-zA-Z0-9]+([a-z])/\U$1/g;
   $result =~ s/[^a-zA-Z0-9]+//g;
 
-  return $result;
+  return CORE::lcfirst($result);
 }
 
 sub chomp {
@@ -178,6 +179,19 @@ sub numified {
   return $self->comparer eq 'numified' ? (0 + $data) : $self->SUPER::numified();
 }
 
+sub pascalcase {
+  my ($self) = @_;
+
+  my $data = $self->get;
+
+  my $result = CORE::ucfirst(CORE::lc($data));
+
+  $result =~ s/[^a-zA-Z0-9]+([a-z])/\U$1/g;
+  $result =~ s/[^a-zA-Z0-9]+//g;
+
+  return $result;
+}
+
 sub prepend {
   my ($self, @args) = @_;
 
@@ -439,7 +453,7 @@ I<Since C<0.01>>
 
   my $camelcase = $string->camelcase;
 
-  # "HelloWorld"
+  # "helloWorld"
 
 =back
 
