@@ -70,6 +70,19 @@ sub data_for_attributes {
   return join "\n\n", @{$data->[0]{data}};
 }
 
+sub data_for_attribute {
+  my ($self, $name) = @_;
+
+  my $data = $self->search({
+    list => 'attribute',
+    name => $name,
+  });
+
+  $self->throw->error if !@$data;
+
+  return join "\n\n", @{$data->[0]{data}};
+}
+
 sub data_for_authors {
   my ($self) = @_;
 
@@ -379,7 +392,7 @@ sub pdml_for_abstract {
   return $text ? ($self->head1('abstract', $text)) : ();
 }
 
-sub pdml_for_attribute {
+sub pdml_for_attribute_type1 {
   my ($self, $name, $is, $pre, $isa, $def) = @_;
 
   my @output;
@@ -395,9 +408,53 @@ sub pdml_for_attribute {
   return ($self->head2($name, @output));
 }
 
+sub pdml_for_attribute_type2 {
+  my ($self, $name) = @_;
+
+  my @output;
+
+  my $metadata = $self->text('metadata', $name);
+  my $signature = $self->text('signature', $name);
+
+  push @output, ($signature, '') if $signature;
+
+  my $text = $self->text('attribute', $name);
+
+  return () if !$text;
+
+  push @output, $text;
+
+  if ($metadata) {
+    local $@;
+    if ($metadata = eval $metadata) {
+      if (my $since = $metadata->{since}) {
+        push @output, "", "I<Since C<$since>>";
+      }
+    }
+  }
+
+  my @results = $self->search({name => $name});
+
+  for my $i (1..(int grep {($$_{list} || '') =~ /^example-\d+/} @results)) {
+    push @output, $self->pdml('example', $i, $name),
+  }
+
+  return ($self->head2($name, @output));
+}
+
 sub pdml_for_attributes {
   my ($self) = @_;
 
+  my $method = $self->text('attributes')
+    ? 'pdml_for_attributes_type1'
+    : 'pdml_for_attributes_type2';
+
+  return $self->$method;
+}
+
+sub pdml_for_attributes_type1 {
+  my ($self) = @_;
+
   my @output;
 
   my $text = $self->text('attributes');
@@ -405,7 +462,7 @@ sub pdml_for_attributes {
   return () if !$text;
 
   for my $line (split /\n/, $text) {
-    push @output, $self->pdml('attribute', (
+    push @output, $self->pdml('attribute_type1', (
       map { split /,\s*/ } split /:\s*/, $line, 2
     ));
   }
@@ -421,6 +478,24 @@ sub pdml_for_attributes {
   return join "\n", @output;
 }
 
+sub pdml_for_attributes_type2 {
+  my ($self) = @_;
+
+  my @output;
+
+  for my $list ($self->search({list => 'attribute'})) {
+    push @output, $self->pdml('attribute_type2', $list->{name});
+  }
+
+  if (@output) {
+    unshift @output, $self->head1('attributes',
+      "This package has the following attributes:",
+    );
+  }
+
+  return join "\n", @output;
+}
+
 sub pdml_for_authors {
   my ($self) = @_;
 
@@ -846,6 +921,26 @@ sub test_for_attributes {
   return $result;
 }
 
+sub test_for_attribute {
+  my ($self, $name, $code) = @_;
+
+  my $data = $self->data('attribute', $name);
+
+  $code ||= sub {
+    length($data) > 1;
+  };
+
+  my $result = $code->();
+
+  ok($result, "=attribute $name");
+
+  my $package = $self->data('name');
+
+  ok($package->can($name), "$package has $name");
+
+  return $result;
+}
+
 sub test_for_authors {
   my ($self, $code) = @_;
 
@@ -1187,6 +1282,20 @@ sub text_for_attributes {
   return $output;
 }
 
+sub text_for_attribute {
+  my ($self, $name) = @_;
+
+  my ($error, $result) = $self->catch('data', 'attribute', $name);
+
+  my $output = [];
+
+  if (!$error) {
+    push @$output, $result;
+  }
+
+  return $output;
+}
+
 sub text_for_authors {
   my ($self) = @_;
 
